@@ -186,7 +186,7 @@ double find_slope(Vector shot_vector, Vector car_to_target) {
     return max(min(d / e, 3), -3);
 };
 
-struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double cap_) {
+struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double cap_) {
     struct jump_shot r;
     r.found = -1;
 
@@ -211,7 +211,7 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, Ve
             Vector right_vector = normalize(sub(pst_crrctn.right, ball_location)).vector;
             r.best_shot_vector = clamp(direction, left_vector, right_vector);
 
-            if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(200))), 1) && fast_shot(car_location, ball_location, time_remaining, cap_, 250)) {
+            if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && fast_shot(car_location, ball_location, time_remaining, cap_, 250)) {
                 double slope = find_slope(r.best_shot_vector, car_to_ball);
                 if (forward_flag && ball_location.z <= 275 && slope > 0) {
                     r.found = 1;
@@ -230,7 +230,7 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, Ve
     return r;
 };
 
-struct jump_shot parse_slice_for_jump_shot(double time_remaining, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double cap_) {
+struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double cap_) {
     struct jump_shot r;
     r.found = -1;
 
@@ -250,7 +250,7 @@ struct jump_shot parse_slice_for_jump_shot(double time_remaining, Vector ball_lo
 
     r.best_shot_vector = direction;
 
-    if ((forward_flag || backward_flag) && in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(200))), 1)) {
+    if ((forward_flag || backward_flag) && in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1)) {
         double slope = find_slope(r.best_shot_vector, car_to_ball);
         if (forward_flag && ball_location.z <= 275 && slope > 0) {
             r.found = 1;
@@ -304,7 +304,7 @@ _Bool is_viable(double time_remaining, double boost_accel, Vector gravity, struc
     return enough_speed && enough_boost && enough_time;
 };
 
-struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining, double boost_accel, Vector gravity, Vector ball_location, struct car me, Vector left_target, Vector right_target, double cap_) {
+struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, Vector left_target, Vector right_target, double cap_) {
     struct aerial_shot r;
     r.found = -1;
 
@@ -315,7 +315,7 @@ struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining
     if (!pst_crrctn.swapped) {
         Vector left_vector = normalize(sub(pst_crrctn.left, ball_location)).vector;
         Vector right_vector = normalize(sub(pst_crrctn.right, ball_location)).vector;
-        r.ball_intercept = sub(ball_location, multiply(clamp(direction, left_vector, right_vector), double_to_vector(175)));
+        r.ball_intercept = sub(ball_location, multiply(clamp(direction, left_vector, right_vector), double_to_vector(best_shot_value)));
 
         if (in_field(r.ball_intercept, 1) && fast_shot(me.location, ball_location, time_remaining, cap_, 250)) {
             double slope = find_slope(r.ball_intercept, car_to_ball);
@@ -328,12 +328,12 @@ struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining
     return r;
 };
 
-struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double boost_accel, Vector gravity, Vector ball_location, struct car me, double cap_) {
+struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, double cap_) {
     struct aerial_shot r;
     r.found = -1;
 
     Vector car_to_ball = sub(ball_location, me.location);
-    r.ball_intercept = sub(ball_location, multiply(normalize(car_to_ball).vector, double_to_vector(175)));
+    r.ball_intercept = sub(ball_location, multiply(normalize(car_to_ball).vector, double_to_vector(best_shot_value)));
 
     if (in_field(r.ball_intercept, 1)) {
         double slope = find_slope(r.ball_intercept, car_to_ball);
@@ -347,52 +347,52 @@ struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double boo
 
 static PyObject *method_parse_slice_for_jump_shot_with_target(PyObject *self, PyObject *args) {
     int car_boost;
-    double time_remaining, cap_;
+    double time_remaining, best_shot_value, cap_;
     Vector ball_location, car_location, car_forward, left_target, right_target;
 
-    if (!PyArg_ParseTuple(args, "d(ddd)(ddd)(ddd)i(ddd)(ddd)d", &time_remaining, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
+    if (!PyArg_ParseTuple(args, "d(ddd)(ddd)(ddd)i(ddd)(ddd)d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
         return NULL;
 
-    struct jump_shot data_struct = parse_slice_for_jump_shot_with_target(time_remaining, ball_location, car_location, car_forward, car_boost, left_target, right_target, cap_);
+    struct jump_shot data_struct = parse_slice_for_jump_shot_with_target(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, left_target, right_target, cap_);
 
     return Py_BuildValue("{s:i,s:(ddd),s:i}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z, "direction", data_struct.direction);
 };
 
 static PyObject *method_parse_slice_for_jump_shot(PyObject *self, PyObject *args) {
     int car_boost;
-    double time_remaining, cap_;
+    double time_remaining, best_shot_value, cap_;
     Vector ball_location, car_location, car_forward;
 
-    if (!PyArg_ParseTuple(args, "d(ddd)(ddd)(ddd)id", &time_remaining, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &cap_))
+    if (!PyArg_ParseTuple(args, "d(ddd)(ddd)(ddd)id", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &cap_))
         return NULL;
 
-    struct jump_shot data_struct = parse_slice_for_jump_shot(time_remaining, ball_location, car_location, car_forward, car_boost, cap_);
+    struct jump_shot data_struct = parse_slice_for_jump_shot(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, cap_);
 
     return Py_BuildValue("{s:i,s:(ddd),s:i}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z, "direction", data_struct.direction);
 };
 
 static PyObject *method_parse_slice_for_aerial_shot_with_target(PyObject *self, PyObject *args) {
     struct car me;
-    double time_remaining, boost_accel, cap_;
+    double time_remaining, best_shot_value, boost_accel, cap_;
     Vector gravity, ball_location, left_target, right_target;
 
-    if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)((ddd)(ddd)(ddd)(ddd)ii)(ddd)(ddd)d", &time_remaining, &boost_accel, &gravity.x, &gravity.y, &gravity.z, &ball_location.x, &ball_location.y, &ball_location.z, &me.location.x, &me.location.y, &me.location.z, &me.velocity.x, &me.velocity.y, &me.velocity.z, &me.up.x, &me.up.y, &me.up.z, &me.forward.x, &me.forward.y, &me.forward.z, &me.airborne, &me.boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
+    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)((ddd)(ddd)(ddd)(ddd)ii)(ddd)(ddd)d", &time_remaining, &best_shot_value, &boost_accel, &gravity.x, &gravity.y, &gravity.z, &ball_location.x, &ball_location.y, &ball_location.z, &me.location.x, &me.location.y, &me.location.z, &me.velocity.x, &me.velocity.y, &me.velocity.z, &me.up.x, &me.up.y, &me.up.z, &me.forward.x, &me.forward.y, &me.forward.z, &me.airborne, &me.boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
         return NULL;
 
-    struct aerial_shot data_struct = parse_slice_for_aerial_shot_with_target(time_remaining, boost_accel, gravity, ball_location, me, left_target, right_target, cap_);
+    struct aerial_shot data_struct = parse_slice_for_aerial_shot_with_target(time_remaining, best_shot_value, boost_accel, gravity, ball_location, me, left_target, right_target, cap_);
 
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "ball_intercept", data_struct.ball_intercept.x, data_struct.ball_intercept.y, data_struct.ball_intercept.z);
 };
 
 static PyObject *method_parse_slice_for_aerial_shot(PyObject *self, PyObject *args) {
     struct car me;
-    double time_remaining, boost_accel, cap_;
+    double time_remaining, best_shot_value, boost_accel, cap_;
     Vector gravity, ball_location;
 
-    if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)((ddd)(ddd)(ddd)(ddd)ii)d", &time_remaining, &boost_accel, &gravity.x, &gravity.y, &gravity.z, &ball_location.x, &ball_location.y, &ball_location.z, &me.location.x, &me.location.y, &me.location.z, &me.velocity.x, &me.velocity.y, &me.velocity.z, &me.up.x, &me.up.y, &me.up.z, &me.forward.x, &me.forward.y, &me.forward.z, &me.airborne, &me.boost, &cap_))
+    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)((ddd)(ddd)(ddd)(ddd)ii)d", &time_remaining, &best_shot_value, &boost_accel, &gravity.x, &gravity.y, &gravity.z, &ball_location.x, &ball_location.y, &ball_location.z, &me.location.x, &me.location.y, &me.location.z, &me.velocity.x, &me.velocity.y, &me.velocity.z, &me.up.x, &me.up.y, &me.up.z, &me.forward.x, &me.forward.y, &me.forward.z, &me.airborne, &me.boost, &cap_))
         return NULL;
 
-    struct aerial_shot data_struct = parse_slice_for_aerial_shot(time_remaining, boost_accel, gravity, ball_location, me, cap_);
+    struct aerial_shot data_struct = parse_slice_for_aerial_shot(time_remaining, best_shot_value, boost_accel, gravity, ball_location, me, cap_);
 
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "ball_intercept", data_struct.ball_intercept.x, data_struct.ball_intercept.y, data_struct.ball_intercept.z);
 };
